@@ -54,18 +54,17 @@ def translate_file(config, target_file, SOURCE_LANG, DEST_LANG):
         source = f.read()
 
     map_file_path = TRANSLATE_DICT_FILES_PATH + '{}.map'.format(target_file)
-    map = {}
+    map = '{}'
     if os.path.isfile(map_file_path):
         with open(map_file_path) as f:
             map = f.read()
-            map = json.loads(map)
 
     # result = lib_inst.davidgu.polycode['@dev'](source, config, map)
 
     fextension = os.path.splitext(target_file)[1]
 
     payload = {'doc': source, 'from': SOURCE_LANG,
-        'to': DEST_LANG, 'map': json.dumps(map, ensure_ascii=False), 'ext':fextension}
+        'to': DEST_LANG, 'map': map, 'ext':fextension}
     # print(payload)
     req = requests.get(SERVER_URL, params=payload)
     # print(req.url)
@@ -75,7 +74,7 @@ def translate_file(config, target_file, SOURCE_LANG, DEST_LANG):
     # result = json.loads(fake_backend(payload))
 
     translated = result['doc']
-    translation_map = json.dumps(result['map'], ensure_ascii=False)
+    translation_map = result['map']
 
     # Translations overwrite the translated file
     translated_file_path = target_file
